pyminideprecator package
========================

Submodules
----------

pyminideprecator.config module
------------------------------

.. automodule:: pyminideprecator.config
   :members:
   :show-inheritance:
   :undoc-members:

pyminideprecator.deprecator module
----------------------------------

.. automodule:: pyminideprecator.deprecator
   :members:
   :show-inheritance:
   :undoc-members:

pyminideprecator.exc module
---------------------------

.. automodule:: pyminideprecator.exc
   :members:
   :show-inheritance:
   :undoc-members:

pyminideprecator.version module
-------------------------------

.. automodule:: pyminideprecator.version
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: pyminideprecator
   :members:
   :show-inheritance:
   :undoc-members:
